@@ -137,7 +137,9 @@ class RateMeta:
 class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
     """Mixin adding rate functions."""
 
-    def __init__(self, rates: dict = None, functions: dict = None) -> None:
+    def __init__(
+        self, rates: dict[str, Rate] | None = None, functions: dict[str, Callable[..., float]] | None = None
+    ) -> None:
         self.rates: Dict[str, Rate] = {}
         self.functions: Dict[str, Callable[..., float]] = {}
         if rates is not None:
@@ -200,13 +202,13 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
         self,
         rate_name: str,
         function: Callable[..., float],
-        substrates: List[str] = None,
-        products: List[str] = None,
-        modifiers: List[str] = None,
-        dynamic_variables: List[str] = None,
-        parameters: List[str] = None,
+        substrates: List[str] | None = None,
+        products: List[str] | None = None,
+        modifiers: List[str] | None = None,
+        dynamic_variables: List[str] | None = None,
+        parameters: List[str] | None = None,
         reversible: bool = False,
-        args: List[str] = None,
+        args: List[str] | None = None,
         check_consistency: bool = True,
         **meta_info: Dict[str, Any],
     ) -> None:
