@@ -955,55 +955,6 @@ class LabelModel(_AbstractRateModel, BaseModel):
             return {k: ones * v for k, v in self._get_fluxes(fcd=fcd).items()}  # type: ignore
         return {k: ones * v for k, v in self._get_fluxes_array(fcd=fcd).items()}  # type: ignore
 
-    def get_fluxes_array(
-        self,
-        y: Union[
-            Dict[str, float],
-            Dict[str, ArrayLike],
-            Dict[str, Array],
-            Array,
-            ArrayLike,
-        ],
-        t: Union[float, ArrayLike, Array] = 0.0,
-    ) -> Array:
-        """Calculate the fluxes at time point(s) t."""
-        return np.array(list(self.get_fluxes_dict(y=y, t=t).values())).T
-
-    def get_fluxes_df(
-        self,
-        y: Union[
-            Dict[str, float],
-            Dict[str, ArrayLike],
-            Dict[str, Array],
-            Array,
-            ArrayLike,
-        ],
-        t: Union[float, ArrayLike, Array] = 0.0,
-    ) -> pd.DataFrame:
-        """Calculate the fluxes at time point(s) t."""
-        if isinstance(t, (int, float)):
-            t = [t]  # type: ignore
-        return pd.DataFrame(data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names())
-
-    def get_right_hand_side(
-        self,
-        y: Union[
-            Dict[str, float],
-            Dict[str, ArrayLike],
-            Dict[str, Array],
-            Array,
-            ArrayLike,
-        ],
-        t: Union[float, ArrayLike, Array] = 0.0,
-    ) -> Dict[str, float]:
-        """Calculate the right hand side of the ODE system."""
-        self._update_derived_parameters()
-        fcd = self.get_full_concentration_dict(y=y, t=t)  # type: ignore
-        fcd_array = [fcd[i] for i in self.get_compounds()]
-        rhs = self._get_rhs(t=t, y=fcd_array)
-        eqs = [f"d{cpd}dt" for cpd in self.get_compounds()]
-        return dict(zip(eqs, rhs))
-
     def get_total_fluxes(
         self,
         rate_base_name: str,
