@@ -272,7 +272,7 @@ class LinearLabelModel(_AbstractStoichiometricModel):
                     y0[f"{base_compound}__{pos}"] = 1 / len(label_positions)
         return y0
 
-    def _get_fluxes(  # type: ignore
+    def _get_fluxes(
         self,
         *,
         fcd: Dict[str, float],
