@@ -54,7 +54,7 @@ class _Simulate(_BaseRateSimulator[Model]):
         y0: Optional[ArrayLike] = None,
         time: Optional[List[Array]] = None,
         results: Optional[List[Array]] = None,
-        parameters: List[Dict[str, float]] = None,
+        parameters: List[Dict[str, float]] | None = None,
     ) -> None:
         """
         Parameters
@@ -73,21 +73,21 @@ class _Simulate(_BaseRateSimulator[Model]):
 
     def plot(
         self,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: Axis = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        ax: Axis | None = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any | None] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         """Plot simulation results for a selection of compounds."""
         compounds = self.model.get_compounds()
